use poise::{
    serenity_prelude::{
        http::CacheHttp,
        model::id::{GuildId, UserId},
        CreateInteractionResponseMessage,
    },
    CreateReply,
};

use crate::consts::{CNC_GUILD, SUBSCRIPTION_ROLES};

pub async fn check_subscription(cache_http: impl CacheHttp, user_id: impl Into<UserId>) -> bool {
    if let Some(subscription_guild) = *CNC_GUILD {
        let guild_member = GuildId::new(subscription_guild).member(cache_http, user_id).await;

        if let Ok(member) = guild_member {
            for role in member.roles {
                if SUBSCRIPTION_ROLES.contains(&role.get()) {
                    return true;
                }
            }
        }

        false
    } else {
        true
    }
}

pub async fn check_guild_subscription(
    cache_http: impl CacheHttp,
    guild_id: impl Into<GuildId>,
) -> bool {
    if let Some(owner) = cache_http.cache().unwrap().guild(guild_id).map(|g| g.owner_id) {
        check_subscription(&cache_http, owner).await
    } else {
        false
    }
}

pub fn reply_to_interaction_response_message(
    reply: CreateReply,
) -> CreateInteractionResponseMessage {
    let mut builder = CreateInteractionResponseMessage::new().embeds(reply.embeds);

    if let Some(components) = reply.components {
        builder = builder.components(components)
    }

    builder
}
